The storebounty_auth_v1 package is a crucial and mandatory component for all
StoreBounty projects. Designed specifically for the StoreBounty company, this
package provides a comprehensive solution for handling user authentication in
StoreBounty applications. It simplifies the process of managing user
authentication, ensuring a secure and seamless login experience for both
customers and administrators.

## Features

Key Features:

1. User Authentication: The storebounty_auth_v1 package offers a robust set of authentication
   features, allowing users to securely register, log in, and manage their accounts within
   StoreBounty applications.
2. Account Management: Users can easily update their profile information, change passwords,
   and manage account settings with the convenience and reliability provided by the package.
3. Access Control: The package includes mechanisms for implementing access control and user
   roles, enabling administrators to define different levels of access and permissions based on
   user roles.
4. Integration with StoreBounty Apps: The storebounty_auth_v1 package seamlessly integrates
   with other StoreBounty packages and applications, ensuring consistent and reliable
   authentication across the entire StoreBounty ecosystem.

## Getting started

The storebounty_auth_v1 package is an essential component for all StoreBounty projects, designed
to work seamlessly in conjunction with the storebounty_init package. As a mandatory package for
StoreBounty applications, it focuses on user authentication and provides a secure and reliable
solution for managing user login and access control.

## Usage

To use the storebounty_auth_v1 package and include the StorebountyAuthPage() widget in your Flutter page, follow these steps:

1. Add the storebounty_auth_v1 package to your pubspec.yaml file. Open the pubspec.yaml file in your Flutter project and add the following line under the dependencies section:

```dart
    dependencies:
        storebounty_auth_v1: ^0.0.1
```

2. Save the pubspec.yaml file and run flutter pub get in your terminal or use the relevant IDE command to fetch and install the storebounty_auth_v1 package.

3. In the Dart file where you want to use the StorebountyAuthPage() widget, import the

```dart
    import 'package:storebounty_auth/storebounty_auth_v1.dart';
```

4. Place the StorebountyAuthPage() widget anywhere within the widget tree of your page. We suggest you add it on a blank page:

```dart
    import 'package:flutter/material.dart';
    import 'package:storebounty_auth/storebounty_auth_v1.dart';

    class AuthScreen extends StatelessWidget {
    const AuthScreen({Key? key}) : super(key: key);

    @override
    Widget build(BuildContext context) {
        return StorebountyAuthPage(
            onLoginSuccess: () {
                //do something when the user credentioals is correct
            },
            onLoginFailed: () {
                //do something when login failed
            },
        );
    }
    }
```

## Additional information

For additional information about the storebounty_auth_v1 package, please visit storebounty.com.
The website provides comprehensive details, documentation, and resources related to the
package, empowering you to maximize its potential in your projects.
