import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:loading_overlay/loading_overlay.dart';
import 'package:storebounty_auth/src/screens/forgotpassword.dart';
import 'package:storebounty_auth/src/screens/otpscreen.dart';
import 'package:storebounty_auth/src/screens/registerscreen.dart';
import 'package:storebounty_auth/src/screens/verifyemail.dart';
import 'package:storebounty_auth/src/widget/alert/alertclass.dart';
import 'package:storebounty_auth/src/widget/authappbar.dart';
import 'package:storebounty_auth/src/widget/custombutton.dart';
import 'package:storebounty_auth/src/widget/customtextfield.dart';
import 'package:storebounty_auth/src/widget/styles/colors.dart';
import 'package:storebounty_auth/src/widget/styles/textstles.dart';
import 'package:storebounty_auth/storebounty_auth_v1.dart';
import 'package:storebounty_init/storebountyinit.dart';

class StorebountyAuthPage extends StatefulWidget {
  final VoidCallback onLoginSuccess;
  final VoidCallback onLoginFailed;
  const StorebountyAuthPage({Key? key, required this.onLoginSuccess, required this.onLoginFailed})
      : super(key: key);

  @override
  State<StorebountyAuthPage> createState() => _StorebountyAuthPageState();
}

class _StorebountyAuthPageState extends State<StorebountyAuthPage> {
  TextEditingController emailCtx = TextEditingController();
  TextEditingController passwordCtx = TextEditingController();
  String displayWidget = "login";

  bool _isLoading = false;

  Color? defaultColor;
  List<dynamic> images = [];
  String currency = "NGN";

  @override
  void initState() {
    getColor();
    // resetDiscountCode();
    super.initState();
  }

  getColor() async {
    var colorString = await StoreBountyInit.getStoreColor() ?? "#000000";
    defaultColor = Color(int.parse("0xff" + colorString.substring(1)));
    var currencySymbol = await StoreBountyInit.getCurrencySymbol();
    currency = currencySymbol!;
    setState(() {});
  }

  loginUser() async {
    try {
      setState(() {
        _isLoading = true;
      });
      var response = await StorebountyAuth.LoginUser(
          {"email": emailCtx.text.trim(), "password": passwordCtx.text.trim()});

      setState(() {
        _isLoading = false;
      });
      
      widget.onLoginSuccess();
    } catch (e) {
      AlertClass.error(context, "$e");
      setState(() {
        _isLoading = false;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    if (displayWidget == "login") {
      return GestureDetector(
        onTap: () {
          FocusScope.of(context).unfocus();
        },
        child: LoadingOverlay(
          isLoading: _isLoading,
          color: defaultColor?.withOpacity(0.2) ?? AppColors.black,
          progressIndicator: CircularProgressIndicator(
            color: defaultColor ?? AppColors.black,
          ),
          child: Scaffold(
            backgroundColor: AppColors.whiteColor,
            appBar: AuthAppBar(
                height: 56,
                showBackBtn: true,
                backBtnFunc: () {
                  Navigator.pop(context);
                }),
            body: Container(
              child: SingleChildScrollView(
                child: Column(
                  children: [
                    SizedBox(
                      height: 41,
                    ),
                    Container(
                        margin: EdgeInsets.symmetric(horizontal: 24),
                        child: CustomTextFormField(
                          labelText: 'Email',
                          hintText: 'Enter your email',
                          controller: emailCtx,
                        )),
                    SizedBox(
                      height: 20,
                    ),
                    Container(
                        margin: EdgeInsets.symmetric(horizontal: 24),
                        child: CustomTextFormField(
                          labelText: 'Password',
                          hintText: 'Enter your password',
                          controller: passwordCtx,
                          obscureText: true,
                        )),
                    InkWell(
                      onTap: () {
                        setState(() {
                          displayWidget = "forgotpassword";
                        });
                      },
                      child: Container(
                        margin:
                            EdgeInsets.symmetric(horizontal: 24, vertical: 10),
                        child: Row(
                          mainAxisAlignment: MainAxisAlignment.end,
                          children: [
                            Text(
                              "Forgot Password?",
                              style: Styles.p3(fontSize: 13),
                            )
                          ],
                        ),
                      ),
                    ),
                    SizedBox(
                      height: 297,
                    ),
                    Container(
                      height: 54,
                      margin: EdgeInsets.symmetric(horizontal: 24),
                      child: Row(
                        children: [
                          Expanded(
                            child: CustomButton(
                              text: "Sign In",
                              color: defaultColor ?? AppColors.black,
                              onPressed: () {
                                loginUser();
                              },
                            ),
                          ),
                        ],
                      ),
                    ),
                    SizedBox(
                      height: 20,
                    ),
                    RichText(
                      text: TextSpan(
                        text: 'Don’t have an account? ',
                        style: Styles.p0(
                            fontSize: 18,
                            color: AppColors.black.withOpacity(0.8)),
                        children: <TextSpan>[
                          TextSpan(
                              text: 'SIGN UP',
                              style: TextStyle(
                                  fontWeight: FontWeight.bold,
                                  color: defaultColor ?? AppColors.black),
                              recognizer: TapGestureRecognizer()
                                ..onTap = () {
                                  setState(() {
                                    displayWidget = "register";
                                  });
                                })
                        ],
                      ),
                    )
                  ],
                ),
              ),
            ),
          ),
        ),
      );
    } else if (displayWidget == "register") {
      return RegisterScreen(
        toSignIn: () {
          setState(() {
            displayWidget = "login";
          });
        },
        onRegisterSuccess: () {
          setState(() {
            displayWidget = "verifyemail";
          });
        },
        onRegisterFailed: () {},
      );
    } else if (displayWidget == "forgotpassword") {
      return ForgotPasswordScreen(
        onOtpSent: () {
          setState(() {
            displayWidget = "otpscreen";
          });
        },
      );
    } else if (displayWidget == "otpscreen") {
      return OtpScreen();
    } else if (displayWidget == "verifyemail") {
      return VerifyEmail(
        emailVerified:(){
          setState(() {
            displayWidget = "login";
          });
        }
      );
    } else {
      return Container();
    }
  }
}
