import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:loading_overlay/loading_overlay.dart';
import 'package:storebounty_auth/src/widget/authappbar.dart';
import 'package:storebounty_auth/src/widget/custombutton.dart';
import 'package:storebounty_auth/src/widget/customtextfield.dart';
import 'package:storebounty_auth/src/widget/styles/colors.dart';
import 'package:storebounty_auth/src/widget/styles/textstles.dart';
import 'package:storebounty_auth/storebounty_auth_v1.dart';
import 'package:storebounty_init/storebountyinit.dart';

class RegisterScreen extends StatefulWidget {
  final VoidCallback toSignIn;
  final VoidCallback onRegisterSuccess;
  final VoidCallback onRegisterFailed;
  const RegisterScreen({Key? key, required this.toSignIn, required this.onRegisterSuccess, required this.onRegisterFailed}) : super(key: key);

  @override
  State<RegisterScreen> createState() => _RegisterScreenState();
}

class _RegisterScreenState extends State<RegisterScreen> {
  TextEditingController firstNameCtx = TextEditingController();
  TextEditingController lastNameCtx = TextEditingController();
  TextEditingController emailRegCtx = TextEditingController();
  TextEditingController phoneNumberCtx = TextEditingController();
  TextEditingController passwordRegCtx = TextEditingController();

  final _formKey = GlobalKey<FormState>();
  bool _isLoading = false;

  Color? defaultColor;
  List<dynamic> images = [];
  String currency = "NGN";

  @override
  void initState() {
    getColor();
    // resetDiscountCode();
    super.initState();
  }

  getColor() async {
    var colorString = await StoreBountyInit.getStoreColor() ?? "#000000";
    defaultColor = Color(int.parse("0xff" + colorString.substring(1)));
    var currencySymbol = await StoreBountyInit.getCurrencySymbol();
    currency = currencySymbol!;
    setState(() {});
  }

  registerUser() async {

    try{

      var data = {
        "email": emailRegCtx.text.trim(),
        "first_name": firstNameCtx.text.trim(),
        "last_name": lastNameCtx.text.trim(),
        "phone": phoneNumberCtx.text.trim(),
        "password": passwordRegCtx.text.trim()
      };

      final response = await StorebountyAuth.register(data);

      widget.onRegisterSuccess();

    }catch(e){

    }

  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        FocusScope.of(context).unfocus();
      },
      child: LoadingOverlay(
        isLoading: _isLoading,
        color: defaultColor?.withOpacity(0.5) ?? AppColors.black,
        progressIndicator: CircularProgressIndicator(
          color: defaultColor ?? AppColors.black,
        ),
        child: Scaffold(
          backgroundColor: AppColors.whiteColor,
          appBar: AuthAppBar(
              height: 56,
              showBackBtn: true,
              title: "Create an Account",
              backBtnFunc: () {
                Navigator.pop(context);
              }),
          body: Container(
            child: SingleChildScrollView(
              child: Column(
                children: [
                  SizedBox(
                    height: 41,
                  ),
                  Form(
                      key: _formKey,
                      child: Column(
                        children: [
                          Container(
                              margin: EdgeInsets.symmetric(horizontal: 24),
                              child: CustomTextFormField(
                                labelText: 'First name',
                                hintText: 'Enter your first name',
                                controller: firstNameCtx,
                                validator: (value) {
                                  if (value == "") {
                                    return "Required";
                                  }
                                  return null;
                                },
                              )),
                          SizedBox(
                            height: 20,
                          ),
                          Container(
                              margin: EdgeInsets.symmetric(horizontal: 24),
                              child: CustomTextFormField(
                                  labelText: 'Last name',
                                  hintText: 'Enter your last name',
                                  controller: lastNameCtx,
                                  validator: (value) {
                                    if (value == "") {
                                      return "Required";
                                    }
                                    return null;
                                  })),
                          SizedBox(
                            height: 20,
                          ),
                          Container(
                              margin: EdgeInsets.symmetric(horizontal: 24),
                              child: CustomTextFormField(
                                  labelText: 'Email',
                                  hintText: 'Enter your email',
                                  controller: emailRegCtx,
                                  validator: (value) {
                                    if (value == "") {
                                      return "Required";
                                    }
                                    return null;
                                  })),
                          SizedBox(
                            height: 20,
                          ),
                          Container(
                              margin: EdgeInsets.symmetric(horizontal: 24),
                              child: CustomTextFormField(
                                  labelText: 'Phone number',
                                  hintText: 'Enter your phone number',
                                  controller: phoneNumberCtx,
                                  validator: (value) {
                                    if (value == "") {
                                      return "Required";
                                    }
                                    return null;
                                  })),
                          SizedBox(
                            height: 20,
                          ),
                          Container(
                              margin: EdgeInsets.symmetric(horizontal: 24),
                              child: CustomTextFormField(
                                  labelText: 'Password',
                                  hintText: 'Enter your password',
                                  controller: passwordRegCtx,
                                  obscureText: true,
                                  validator: (value) {
                                    if (value == "") {
                                      return "Required";
                                    }
                                    return null;
                                  })),
                        ],
                      )),
                  // Container(
                  //   margin: EdgeInsets.symmetric(horizontal: 24, vertical: 10),
                  //   child: Row(
                  //     mainAxisAlignment: MainAxisAlignment.end,
                  //     children: [
                  //       Text(
                  //         "Forgot Password?",
                  //         style: Styles.p3(fontSize: 13),
                  //       )
                  //     ],
                  //   ),
                  // ),
                  SizedBox(
                    height: 70,
                  ),
                  Container(
                    height: 54,
                    margin: EdgeInsets.symmetric(horizontal: 24),
                    child: Row(
                      children: [
                        Expanded(
                          child: CustomButton(
                            text: "Sign Up",
                            color: defaultColor ?? AppColors.black,
                            onPressed: () {
                              if (!_formKey.currentState!.validate()) {
                                return;
                              }
                              registerUser();
                            },
                          ),
                        ),
                      ],
                    ),
                  ),
                  SizedBox(
                    height: 20,
                  ),
                  RichText(
                    text: TextSpan(
                      text: 'Don’t have an account? ',
                      style: Styles.p0(
                          fontSize: 18,
                          color: AppColors.black.withOpacity(0.8)),
                      children: <TextSpan>[
                        TextSpan(
                            text: 'SIGN IN',
                            style: TextStyle(
                                fontWeight: FontWeight.bold,
                                color: defaultColor ?? AppColors.black),
                            recognizer: TapGestureRecognizer()
                              ..onTap = () {
                                widget.toSignIn();
                              })
                      ],
                    ),
                  ),
                  SizedBox(
                    height: 20,
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}
