import 'package:flutter/material.dart';
import 'package:storebounty_auth/src/widget/styles/colors.dart';
import 'package:storebounty_auth/src/widget/styles/textstles.dart';

class CustomTextFormField extends StatelessWidget {
  final String? labelText;
  final String hintText;
  final FormFieldValidator<String>? validator;
  final TextEditingController? controller;
  final ValueChanged<String>? onChanged;
  final TextInputType? keyboardType;
  final TextInputAction? textInputAction;
  final bool obscureText;
  final Widget? surfixWidget;
  final Widget? rightWidget;

  CustomTextFormField({
    this.labelText,
    required this.hintText,
    this.validator,
    this.controller,
    this.onChanged,
    this.keyboardType,
    this.textInputAction,
    this.obscureText = false, this.surfixWidget, this.rightWidget,
  });

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Visibility(
          visible: labelText != null,
          child: Column(
            children: [
              Text(
                labelText ?? "",
                style: Styles.p0(fontSize: 16, fontWeight: FontWeight.w500),
              ),
              SizedBox(height: 2),
            ],
          ),
        ),
        Row(
          children: [
            Expanded(
              child: TextFormField(
                validator: validator,
                controller: controller,
                onChanged: onChanged,
                keyboardType: keyboardType,
                textInputAction: textInputAction,
                obscureText: obscureText,
                decoration: InputDecoration(
                  contentPadding: EdgeInsets.symmetric(vertical: 10, horizontal: 15),
                  hintText: hintText,
                  hintStyle: Styles.p3(color: AppColors.black.withOpacity(0.5)),
                  enabledBorder: OutlineInputBorder(
                    borderSide: BorderSide(color: Color(0xff97928c).withOpacity(0.5), width: 0.4)
                  ),
                  focusedBorder: OutlineInputBorder(
                    borderSide: BorderSide(color: AppColors.defaultColor.withOpacity(0.5), width: 0.4)
                  ),
                  border: OutlineInputBorder(

                    borderSide: BorderSide(color: Color(0xff97928).withOpacity(0.5), width: 0.4)
                  ),
                  suffixIcon: surfixWidget ?? SizedBox.shrink(),


                ),


              ),
            ),
            Visibility(
              visible: rightWidget != null,
              child: Row(
                children: [
                  SizedBox(width: 10,),
                  rightWidget ?? Container()
                ],
              ),
            )
          ],
        ),
      ],
    );
  }
}
